@@ -470,8 +470,8 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = False,
 
 
 
-## -single community with gray connection -## 
-def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_folder='gray_units/',height='600px', width='100%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+## -single community with gray connection DEPRECATED-## 
+def gray_unit1(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_folder='gray_units/',height='600px', width='100%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
     """ 
         cdn=['remote','local'] more in pyvis 
         plot_graph = False for google colab 
@@ -611,6 +611,171 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
     return colorGrayDF
   
 
+
+## -single community with gray connection All in One included -## 
+def gray_unit(nnColor_df,Gdc,all_edges,comLen = False, allinOne = 1, plot_graph = False, save_folder='gray_units/',height='600px', width='80%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+    """ allinOne = 1 , all gray unit into one html 
+        cdn=['remote','local'] more in pyvis 
+        plot_graph = False for google colab 
+        comLen : the first comLen gray communites in
+    """    
+    
+    if comLen == False:
+        com_len = len(set(nnColor_df.community_nn.to_list()))
+    else:
+        com_len = comLen
+    
+    commus= []
+    colorEdges = []
+    colorNodes = []
+    grayEdges = []
+    grayNodes = []
+    
+    if allinOne ==1:
+        ntc3=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook,cdn_resources=cdn)
+        ntc3.set_edge_smooth('cubicBezier')
+    for community_index in range(com_len):
+      com_DF1 = nnColor_df[nnColor_df['community_nn'] == community_index +1]
+      comNodes_ori = com_DF1.node.to_list()
+      comEdges0 = com_DF1.edges.to_list()
+      comNodes= []
+      comEdges = []
+      for edges in comEdges0:
+        for edge in edges:
+          comEdges.append(edge)
+          for node in edge:
+            comNodes.append(node)
+      #print(len(comNodes))
+      comNodes = sorted(set(comNodes))
+      #print(len(comNodes))
+      #print(len(comEdges))
+      #print(len(set(comEdges)))
+      comEdges = sorted(set(comEdges))
+      if allinOne ==0:
+          ntc3=Network(height=height, width=width,heading=heading,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook,cdn_resources=cdn)
+          ntc3.set_edge_smooth('cubicBezier')
+
+
+      for node in comNodes:
+          color_v =""
+          color_n = ""
+          color_a =""
+          if node in comNodes_ori:
+            color_v = 'red'
+            color_n ='blue'
+            color_a ='brown'
+          else:
+            color_v = 'gray'
+            color_n = 'gray'
+            color_a = 'gray'
+          
+
+          #node = iGd.vs[index]['name']
+          #node1 = node[:-2]
+          node1 = re.sub(r'[2][a-zA-Z]{2}',"2",node)
+          if allinOne ==1:
+              node1 = node1+'_'+str(community_index) 
+          if 'vvv' in node:
+            shape = 'square'   # shape  image, circularImage, diamond, dot, star, triangle, triangleDown, square and icon.
+            degree = dict(Gdc.degree)[node]
+            title = node +':'+str(degree)
+            ntc3.add_node(node1,title = node[:-4].replace('2vvv'," ") +':'+str(degree), value =.1*degree, color = color_v,shape =shape) #value=degree
+          elif 'aaa' in node:
+          
+            shape = 'triangle'
+            degree = dict(Gdc.degree)[node]
+            title = node +':'+str(degree)
+            ntc3.add_node(node1,title = node[:-4].replace('2aaa'," ") +':'+str(degree),value =.1*degree, color = color_a,shape =shape) #value=degree
+          elif 'nnn' in node:
+            shape = 'dot'
+            degree = dict(Gdc.degree)[node]
+            title = node +':'+str(degree)
+            #print('node1',node1)
+            ntc3.add_node(node1,title = node[:-4].replace('2nnn'," ") +':'+str(degree),value=.5*degree,color = color_n, shape =shape) #value=degree
+            
+
+      for edge in all_edges:
+        for edge1 in comEdges:
+          if edge1 == edge[:2]:
+            elabel = str(edge[2])
+            #value = int(edge[2])*.5
+            value = math.log(int(edge[2]),2)
+            #print(elabel)
+
+            edge0 = re.sub(r'[2][a-zA-Z]{2}',"2",edge[0])
+            edge1 = re.sub(r'[2][a-zA-Z]{2}',"2",edge[1])
+            if allinOne ==1:
+                edge0 = edge0+'_'+str(community_index) 
+                edge1 = edge1+'_'+str(community_index) 
+            #print(edge0, edge1)
+            ntc3.add_edge(edge0,edge1, title = elabel,width = value)
+            #ntc3.add_edge(edge[0][:-2],edge[1][:-2], title = elabel,width = value)
+      ntc3.show_buttons(filter_=['physics'])
+      if allinOne ==0:
+          if plot_graph:
+            if community_index == com_len-1: 
+                display(ntc3.show(str(community_index) + '_gray_unit.html'))
+                #display(HTML(str(community_index) + '_gray_unit.html'))
+          else:
+            if community_index == com_len-1: 
+                 ntc3.show(str(community_index) + '_gray_unit.html') # google colab
+                 display(HTML(str(community_index) + '_gray_unit.html'))       
+          if save_folder:
+            ntc3.save_graph(save_folder+ '/{}.html'.format(community_index +1))
+
+      # gray_color edges dataframe 
+      gray_nodes = [x for x in comNodes if x not in comNodes_ori]
+      gray_edges = []
+      color_edges = []
+      for edge in all_edges:
+        for edge1 in comEdges:
+          if edge1 == edge[:2]:
+            if len(gray_nodes)>0:
+                if  edge1[0] not in gray_nodes and edge1[1] not in gray_nodes:
+                  color_edges.append(edge)
+                else:
+                  gray_edges.append(edge)
+
+
+      color_nodes = comNodes_ori
+      #if len(gray_nodes)<1:
+        #gray_nodes = []
+      #set(color_edges),set(color_nodes),set(gray_edges),set(gray_nodes)
+      grayNodeDs= []
+      for node in gray_nodes:
+        degree = dict(Gdc.degree)[node]
+        nodeD = (node,degree)
+        grayNodeDs.append(nodeD)
+      colorNodeDs = []
+      for node in color_nodes:
+        degree = dict(Gdc.degree)[node]
+        nodeD = (node,degree)
+        colorNodeDs.append(nodeD)      
+    
+      
+      commus.append(community_index)
+      colorEdges.append(set(color_edges))
+      colorNodes.append(set(colorNodeDs))
+      grayEdges.append(set(gray_edges))
+      grayNodes.append(set(grayNodeDs))
+    colorGrayDF = pd.DataFrame({'commus': commus,'colorEdges':colorEdges,'colorNodes':colorNodes,'grayEdges':grayEdges,'grayNodes':grayNodes})
+    
+    if allinOne ==1:
+        if plot_graph:
+            display(ntc3.show(str(community_index) + '_gray_unit.html'))
+                #display(HTML(str(community_index) + '_gray_unit.html'))
+        else:
+            ntc3.show(str(community_index) + '_gray_unit.html') # google colab
+            display(HTML(str(community_index) + '_gray_unit.html'))       
+        if save_folder:
+            ntc3.save_graph(save_folder+ '/{}.html'.format('allinOne_gray'))
+    
+    return colorGrayDF
+  
+
+
+
+
 def compare_net(allWedges, weight_K=1, specEdges1 = False,specEdges2 = False, specNodes1=False,specNodes2=False, color1= 'red', color2 = 'green', save_add = False,heading = 'Compared Network',core_K = 1 , plot_graph = False, height='600px',width='100%',bgcolor='white', font_color="black",directed = True,notebook =True,cdn='remote'):
     """ 
     allWEdges  of list of weighted edges including SharedA, ShareB, SpecificA, SpecificB edges 
