@@ -1,6 +1,6 @@
 from keypartx.basemodes.avn_base import countFreq
 import pandas as pd
-
+import re
 import leidenalg as la
 import igraph as ig 
 import networkx as nx
@@ -255,7 +255,85 @@ class unit2sent:
     knWedges = knWedge_vs + knWedge_as + knWedge_ns
     return  avn2cn,knWedges
   
-  
+
+
+
+def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =.01 , iPOS = 5 ):
+    """ 
+    includeGray: include gray node and edge
+    ncR: core noun degree/ core nouns degree sum
+    vdR: verb to core noun edge weight/ verbs to core noun edges sum
+    adR: adjective to core noun edge weight/ adjectives to core noun edges sum
+    ndR: noun to core noun edge weight/ nouns to core noun edges sum
+    iPOS: choose first 5 knVerbs, knAdjs, knNouns 
+    """
+    unitDFs = []
+    for i in range(len(colorGrayDF)): 
+
+        com_nC1 = colorGrayDF.colorNodes.to_list()[i]
+        com_eC1 = colorGrayDF.colorEdges.to_list()[i]
+        com_nG1 = colorGrayDF.grayNodes.to_list()[i]
+        com_eG1 = colorGrayDF.grayEdges.to_list()[i]
+
+        com_nC1b = [x[0][:-4] for x in com_nC1] # get the color node list without degree
+
+        if includeGray:
+            commu1_nodes = {*com_nC1,*com_nG1}  # combine gray and color node 
+            commu1_edges = {*com_eC1,*com_eG1}   # combine gray and color edges 
+        else:
+            commu1_nodes = com_nC1
+            commu1_edges = com_eC1
+
+        #print(len(commu1_nodes), len(commu1_edges))
+
+        # from keypartx.basemodes.net_base import unit2sent 
+        # gray nodes will not have any in-edge
+        us = unit2sent(commu1_nodes,commu1_edges)
+        #print(us.corenoun(ncR=0.01))
+        c_nouns = us.corenoun(ncR=ncR)[0]
+        c_nounDs = us.corenoun(ncR=ncR)[1]
+        #print(c_nouns,c_nounDs)
+
+        keyNouns = []
+        knVERBs = []
+        knADJs = []
+        knNOUNs = []
+        nodeColors = []
+        keyNounFreqs = []
+        knWedges = []
+        first_i_pos = iPOS # choose first 5 knVerbs, knAdjs, knNouns
+        for c_noun, c_nounD, in zip(c_nouns,c_nounDs ):
+          avn2c,knWedge = us.avn2coren(c_noun,c_nounD = c_nounD, vdR = vdR, adR =adR,ndR =ndR)
+          knWedge.sort(key=lambda x:x[2],reverse=True)
+          #print(avn2c)
+          keyNoun = list(avn2c.keys())[0]
+          verb = list(avn2c.values())[0][0][:first_i_pos]
+          adj = list(avn2c.values())[0][1][:first_i_pos]
+          noun = list(avn2c.values())[0][2][:first_i_pos]
+          if any(len(x) for x in list(avn2c.values())[0])>0:
+            keyNouns.append(keyNoun)
+            knVERBs.append(verb)
+            knADJs.append(adj)
+            knNOUNs.append(noun)
+            keyNoun1 = re.sub("\((.*?)\)", "", keyNoun) # replace key noun menu(10) to menu 
+            keyNounFreq = int(re.findall("\((.*?)\)", keyNoun)[0])
+            keyNounFreqs.append(keyNounFreq)
+            knWedges.append(knWedge)
+            #print(keyNoun1, com_nC1b , ' testtttttt')
+            if keyNoun1 in com_nC1b:
+                ncolor = 'color'
+            else:
+                ncolor = 'gray'
+            nodeColors.append(ncolor)
+
+        
+        unitDF = pd.DataFrame({'community':i, 'keyNouns': keyNouns,'keyNounsD':keyNounFreqs,'keyNounColors': nodeColors,'knVERBs':knVERBs,'knADJs':knADJs,'knNOUNs':knNOUNs,'knWedges':knWedges})
+        unitDFs.append(unitDF)
+    unitDF_all = pd.concat(unitDFs)
+    unitDF_all['keyNounsD'] = unitDF_all['keyNounsD'].astype('Int64')
+    return unitDF_all
+
+
   
   
 # find specific nodes or edges for compare networks in two set 
