@@ -875,8 +875,12 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
 
 ## --target plot --
 
-def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size = 20, word_close = 5, arc_rad= -0.3):
-  """green curve: Adjective2Noun,  red curve: Verb2Noun,  blue cure: Noun2Noun"""
+def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size = 15, word_close = 5, connectionstyle = "arc,angleA=90,angleB=90,armA=30,armB=35,rad=0.3", node_size = 1000):
+  """green curve: Adjective2Noun,  red curve: Verb2Noun,  blue cure: Noun2Noun
+     connectionstyle: https://matplotlib.org/stable/gallery/userdemo/connectionstyle_demo.html  
+     # "arc3,rad=0.3" ,  "bar,fraction=-0.3" , "arc,angleA=90,angleB=90,armA=30,armB=35,rad=0.3"
+  """
+  
   words = text_T.split()
   #figure(figsize=(10,9))
   fig, _ = plt.subplots()
@@ -924,7 +928,7 @@ def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size =
     #print(node)
     #print('startP:',startP)
 
-    G.add_node(node,pos=(startP,20), type=type1,color =color1)
+    G.add_node(node,pos=(startP,30), type=type1,color =color1)
     
   for edge in avnEdges:
     edgestring = "".join(edge)
@@ -967,7 +971,7 @@ def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size =
   edges = G.edges()
   ecolors = [G[u][v]['color'] for u,v in edges]
   weights = [G[u][v]['weight'] for u,v in edges]
-  nx.draw(G, pos, edge_color=ecolors,node_size = 1000,font_size =font_size,node_color='None',font_color ='black', width=weights,with_labels= True, labels = node_attrs,connectionstyle="arc3,rad={}".format(arc_rad),)
+  nx.draw(G, pos, edge_color=ecolors,node_size = node_size,font_size =font_size,node_color='None',font_color ='black', width=weights,with_labels= True, labels = node_attrs,connectionstyle= connectionstyle,)
   if saveAdd:
     plt.savefig(saveAdd)
   else:
